"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.workload_v1_api import WorkloadV1Api  # noqa: E501


class TestWorkloadV1Api(unittest.TestCase):
    """WorkloadV1Api unit test stubs"""

    def setUp(self):
        self.api = WorkloadV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_migration(self):
        """Test case for abort_migration

        Abort Workload Migration operation  # noqa: E501
        """
        pass

    def test_abort_migration1(self):
        """Test case for abort_migration1

        Abort Workload Migration operation  # noqa: E501
        """
        pass

    def test_add_workload(self):
        """Test case for add_workload

        Create Workload object  # noqa: E501
        """
        pass

    def test_add_workload1(self):
        """Test case for add_workload1

        Create Workload object  # noqa: E501
        """
        pass

    def test_add_workload_group(self):
        """Test case for add_workload_group

        Create WorkloadGroup object  # noqa: E501
        """
        pass

    def test_add_workload_group1(self):
        """Test case for add_workload_group1

        Create WorkloadGroup object  # noqa: E501
        """
        pass

    def test_delete_workload(self):
        """Test case for delete_workload

        Delete Workload object  # noqa: E501
        """
        pass

    def test_delete_workload1(self):
        """Test case for delete_workload1

        Delete Workload object  # noqa: E501
        """
        pass

    def test_delete_workload_group(self):
        """Test case for delete_workload_group

        Delete WorkloadGroup object  # noqa: E501
        """
        pass

    def test_delete_workload_group1(self):
        """Test case for delete_workload_group1

        Delete WorkloadGroup object  # noqa: E501
        """
        pass

    def test_final_sync_migration(self):
        """Test case for final_sync_migration

        Initiates the final sync for the Workload Migration operation  # noqa: E501
        """
        pass

    def test_final_sync_migration1(self):
        """Test case for final_sync_migration1

        Initiates the final sync for the Workload Migration operation  # noqa: E501
        """
        pass

    def test_finish_migration(self):
        """Test case for finish_migration

        Finish Workload Migration operation  # noqa: E501
        """
        pass

    def test_finish_migration1(self):
        """Test case for finish_migration1

        Finish Workload Migration operation  # noqa: E501
        """
        pass

    def test_get_endpoint(self):
        """Test case for get_endpoint

        Get Endpoint object  # noqa: E501
        """
        pass

    def test_get_endpoint1(self):
        """Test case for get_endpoint1

        Get Endpoint object  # noqa: E501
        """
        pass

    def test_get_workload(self):
        """Test case for get_workload

        Get Workload object  # noqa: E501
        """
        pass

    def test_get_workload1(self):
        """Test case for get_workload1

        Get Workload object  # noqa: E501
        """
        pass

    def test_get_workload_group(self):
        """Test case for get_workload_group

        Get WorkloadGroup object  # noqa: E501
        """
        pass

    def test_get_workload_group1(self):
        """Test case for get_workload_group1

        Get WorkloadGroup object  # noqa: E501
        """
        pass

    def test_label_workload(self):
        """Test case for label_workload

        Label Workload object  # noqa: E501
        """
        pass

    def test_label_workload1(self):
        """Test case for label_workload1

        Label Workload object  # noqa: E501
        """
        pass

    def test_label_workload_group(self):
        """Test case for label_workload_group

        Label WorkloadGroup object  # noqa: E501
        """
        pass

    def test_label_workload_group1(self):
        """Test case for label_workload_group1

        Label WorkloadGroup object  # noqa: E501
        """
        pass

    def test_list_endpoint(self):
        """Test case for list_endpoint

        List Endpoint objects  # noqa: E501
        """
        pass

    def test_list_endpoint1(self):
        """Test case for list_endpoint1

        List Endpoint objects  # noqa: E501
        """
        pass

    def test_list_workload(self):
        """Test case for list_workload

        List Workload objects  # noqa: E501
        """
        pass

    def test_list_workload1(self):
        """Test case for list_workload1

        List Workload objects  # noqa: E501
        """
        pass

    def test_list_workload_group(self):
        """Test case for list_workload_group

        List WorkloadGroup objects  # noqa: E501
        """
        pass

    def test_list_workload_group1(self):
        """Test case for list_workload_group1

        List WorkloadGroup objects  # noqa: E501
        """
        pass

    def test_start_migration(self):
        """Test case for start_migration

        Start Workload Migration operation  # noqa: E501
        """
        pass

    def test_start_migration1(self):
        """Test case for start_migration1

        Start Workload Migration operation  # noqa: E501
        """
        pass

    def test_update_workload(self):
        """Test case for update_workload

        Update Workload object  # noqa: E501
        """
        pass

    def test_update_workload1(self):
        """Test case for update_workload1

        Update Workload object  # noqa: E501
        """
        pass

    def test_update_workload_group(self):
        """Test case for update_workload_group

        Update WorkloadGroup object  # noqa: E501
        """
        pass

    def test_update_workload_group1(self):
        """Test case for update_workload_group1

        Update WorkloadGroup object  # noqa: E501
        """
        pass

    def test_watch_endpoint(self):
        """Test case for watch_endpoint

        Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_endpoint1(self):
        """Test case for watch_endpoint1

        Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload(self):
        """Test case for watch_workload

        Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload1(self):
        """Test case for watch_workload1

        Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload_group(self):
        """Test case for watch_workload_group

        Watch WorkloadGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload_group1(self):
        """Test case for watch_workload_group1

        Watch WorkloadGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
