"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_certificate import SecurityCertificate
globals()['SecurityCertificate'] = SecurityCertificate
from pensando_dss.psm.psm.model.security_auto_msg_certificate_watch_helper_watch_event import SecurityAutoMsgCertificateWatchHelperWatchEvent


class TestSecurityAutoMsgCertificateWatchHelperWatchEvent(unittest.TestCase):
    """SecurityAutoMsgCertificateWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityAutoMsgCertificateWatchHelperWatchEvent(self):
        """Test SecurityAutoMsgCertificateWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityAutoMsgCertificateWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
