"""
    Orchestration API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.orchestration_orchestrator import OrchestrationOrchestrator
globals()['OrchestrationOrchestrator'] = OrchestrationOrchestrator
from pensando_dss.psm.psm.model.orchestration_auto_msg_orchestrator_watch_helper_watch_event import OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent


class TestOrchestrationAutoMsgOrchestratorWatchHelperWatchEvent(unittest.TestCase):
    """OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrchestrationAutoMsgOrchestratorWatchHelperWatchEvent(self):
        """Test OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
