"""
    Tokenauth API reference

    APIs to generate node auth tokens    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.tokenauth_v1_api import TokenauthV1Api  # noqa: E501


class TestTokenauthV1Api(unittest.TestCase):
    """TokenauthV1Api unit test stubs"""

    def setUp(self):
        self.api = TokenauthV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_generate_node_token(self):
        """Test case for get_generate_node_token

        """
        pass


if __name__ == '__main__':
    unittest.main()
