"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.routing_v1_api import RoutingV1Api  # noqa: E501


class TestRoutingV1Api(unittest.TestCase):
    """RoutingV1Api unit test stubs"""

    def setUp(self):
        self.api = RoutingV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_health_z(self):
        """Test case for get_health_z

        """
        pass

    def test_get_list_neighbors(self):
        """Test case for get_list_neighbors

        """
        pass

    def test_get_list_routes1(self):
        """Test case for get_list_routes1

        """
        pass

    def test_post_list_routes(self):
        """Test case for post_list_routes

        """
        pass


if __name__ == '__main__':
    unittest.main()
