"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.network_virtual_router_peering_group import NetworkVirtualRouterPeeringGroup
globals()['ApiListMeta'] = ApiListMeta
globals()['NetworkVirtualRouterPeeringGroup'] = NetworkVirtualRouterPeeringGroup
from pensando_dss.psm.psm.model.network_virtual_router_peering_group_list import NetworkVirtualRouterPeeringGroupList


class TestNetworkVirtualRouterPeeringGroupList(unittest.TestCase):
    """NetworkVirtualRouterPeeringGroupList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkVirtualRouterPeeringGroupList(self):
        """Test NetworkVirtualRouterPeeringGroupList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkVirtualRouterPeeringGroupList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
