"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.search_error import SearchError
from pensando_dss.psm.model.search_rules_by_policy_name import SearchRulesByPolicyName
globals()['SearchError'] = SearchError
globals()['SearchRulesByPolicyName'] = SearchRulesByPolicyName
from pensando_dss.psm.psm.model.search_policy_search_response import SearchPolicySearchResponse


class TestSearchPolicySearchResponse(unittest.TestCase):
    """SearchPolicySearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchPolicySearchResponse(self):
        """Test SearchPolicySearchResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchPolicySearchResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
