"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.security_v1_api import SecurityV1Api  # noqa: E501


class TestSecurityV1Api(unittest.TestCase):
    """SecurityV1Api unit test stubs"""

    def setUp(self):
        self.api = SecurityV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_app(self):
        """Test case for add_app

        Create App object  # noqa: E501
        """
        pass

    def test_add_app1(self):
        """Test case for add_app1

        Create App object  # noqa: E501
        """
        pass

    def test_add_ip_sec_policy(self):
        """Test case for add_ip_sec_policy

        Create IPSecPolicy object  # noqa: E501
        """
        pass

    def test_add_ip_sec_policy1(self):
        """Test case for add_ip_sec_policy1

        Create IPSecPolicy object  # noqa: E501
        """
        pass

    def test_add_network_security_policy(self):
        """Test case for add_network_security_policy

        Create NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_add_network_security_policy1(self):
        """Test case for add_network_security_policy1

        Create NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_delete_app(self):
        """Test case for delete_app

        Delete App object  # noqa: E501
        """
        pass

    def test_delete_app1(self):
        """Test case for delete_app1

        Delete App object  # noqa: E501
        """
        pass

    def test_delete_ip_sec_policy(self):
        """Test case for delete_ip_sec_policy

        Delete IPSecPolicy object  # noqa: E501
        """
        pass

    def test_delete_ip_sec_policy1(self):
        """Test case for delete_ip_sec_policy1

        Delete IPSecPolicy object  # noqa: E501
        """
        pass

    def test_delete_network_security_policy(self):
        """Test case for delete_network_security_policy

        Delete NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_delete_network_security_policy1(self):
        """Test case for delete_network_security_policy1

        Delete NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_get_app(self):
        """Test case for get_app

        Get App object  # noqa: E501
        """
        pass

    def test_get_app1(self):
        """Test case for get_app1

        Get App object  # noqa: E501
        """
        pass

    def test_get_firewall_profile(self):
        """Test case for get_firewall_profile

        Get FirewallProfile object  # noqa: E501
        """
        pass

    def test_get_firewall_profile1(self):
        """Test case for get_firewall_profile1

        Get FirewallProfile object  # noqa: E501
        """
        pass

    def test_get_ip_sec_policy(self):
        """Test case for get_ip_sec_policy

        Get IPSecPolicy object  # noqa: E501
        """
        pass

    def test_get_ip_sec_policy1(self):
        """Test case for get_ip_sec_policy1

        Get IPSecPolicy object  # noqa: E501
        """
        pass

    def test_get_network_security_policy(self):
        """Test case for get_network_security_policy

        Get NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_get_network_security_policy1(self):
        """Test case for get_network_security_policy1

        Get NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_label_app(self):
        """Test case for label_app

        Label App object  # noqa: E501
        """
        pass

    def test_label_app1(self):
        """Test case for label_app1

        Label App object  # noqa: E501
        """
        pass

    def test_label_firewall_profile(self):
        """Test case for label_firewall_profile

        Label FirewallProfile object  # noqa: E501
        """
        pass

    def test_label_firewall_profile1(self):
        """Test case for label_firewall_profile1

        Label FirewallProfile object  # noqa: E501
        """
        pass

    def test_label_ip_sec_policy(self):
        """Test case for label_ip_sec_policy

        Label IPSecPolicy object  # noqa: E501
        """
        pass

    def test_label_ip_sec_policy1(self):
        """Test case for label_ip_sec_policy1

        Label IPSecPolicy object  # noqa: E501
        """
        pass

    def test_label_network_security_policy(self):
        """Test case for label_network_security_policy

        Label NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_label_network_security_policy1(self):
        """Test case for label_network_security_policy1

        Label NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_list_app(self):
        """Test case for list_app

        List App objects  # noqa: E501
        """
        pass

    def test_list_app1(self):
        """Test case for list_app1

        List App objects  # noqa: E501
        """
        pass

    def test_list_firewall_profile(self):
        """Test case for list_firewall_profile

        List FirewallProfile objects  # noqa: E501
        """
        pass

    def test_list_firewall_profile1(self):
        """Test case for list_firewall_profile1

        List FirewallProfile objects  # noqa: E501
        """
        pass

    def test_list_ip_sec_policy(self):
        """Test case for list_ip_sec_policy

        List IPSecPolicy objects  # noqa: E501
        """
        pass

    def test_list_ip_sec_policy1(self):
        """Test case for list_ip_sec_policy1

        List IPSecPolicy objects  # noqa: E501
        """
        pass

    def test_list_network_security_policy(self):
        """Test case for list_network_security_policy

        List NetworkSecurityPolicy objects  # noqa: E501
        """
        pass

    def test_list_network_security_policy1(self):
        """Test case for list_network_security_policy1

        List NetworkSecurityPolicy objects  # noqa: E501
        """
        pass

    def test_update_app(self):
        """Test case for update_app

        Update App object  # noqa: E501
        """
        pass

    def test_update_app1(self):
        """Test case for update_app1

        Update App object  # noqa: E501
        """
        pass

    def test_update_firewall_profile(self):
        """Test case for update_firewall_profile

        Update FirewallProfile object  # noqa: E501
        """
        pass

    def test_update_firewall_profile1(self):
        """Test case for update_firewall_profile1

        Update FirewallProfile object  # noqa: E501
        """
        pass

    def test_update_ip_sec_policy(self):
        """Test case for update_ip_sec_policy

        Update IPSecPolicy object  # noqa: E501
        """
        pass

    def test_update_ip_sec_policy1(self):
        """Test case for update_ip_sec_policy1

        Update IPSecPolicy object  # noqa: E501
        """
        pass

    def test_update_network_security_policy(self):
        """Test case for update_network_security_policy

        Update NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_update_network_security_policy1(self):
        """Test case for update_network_security_policy1

        Update NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_watch_app(self):
        """Test case for watch_app

        Watch App objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_app1(self):
        """Test case for watch_app1

        Watch App objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_firewall_profile(self):
        """Test case for watch_firewall_profile

        Watch FirewallProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_firewall_profile1(self):
        """Test case for watch_firewall_profile1

        Watch FirewallProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ip_sec_policy(self):
        """Test case for watch_ip_sec_policy

        Watch IPSecPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ip_sec_policy1(self):
        """Test case for watch_ip_sec_policy1

        Watch IPSecPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_security_policy(self):
        """Test case for watch_network_security_policy

        Watch NetworkSecurityPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_security_policy1(self):
        """Test case for watch_network_security_policy1

        Watch NetworkSecurityPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
