"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.workload_propagation_status import WorkloadPropagationStatus
from pensando_dss.psm.model.workload_workload_intf_status import WorkloadWorkloadIntfStatus
from pensando_dss.psm.model.workload_workload_migration_status import WorkloadWorkloadMigrationStatus
globals()['WorkloadPropagationStatus'] = WorkloadPropagationStatus
globals()['WorkloadWorkloadIntfStatus'] = WorkloadWorkloadIntfStatus
globals()['WorkloadWorkloadMigrationStatus'] = WorkloadWorkloadMigrationStatus
from pensando_dss.psm.psm.model.workload_workload_status import WorkloadWorkloadStatus


class TestWorkloadWorkloadStatus(unittest.TestCase):
    """WorkloadWorkloadStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWorkloadWorkloadStatus(self):
        """Test WorkloadWorkloadStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WorkloadWorkloadStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
