"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.monitoring_interface_mirror import MonitoringInterfaceMirror
from pensando_dss.psm.model.monitoring_match_rule import MonitoringMatchRule
from pensando_dss.psm.model.monitoring_mirror_collector import MonitoringMirrorCollector
from pensando_dss.psm.model.monitoring_mirror_source import MonitoringMirrorSource
from pensando_dss.psm.model.monitoring_mirror_start_conditions import MonitoringMirrorStartConditions
from pensando_dss.psm.model.monitoring_workload_mirror import MonitoringWorkloadMirror
globals()['MonitoringInterfaceMirror'] = MonitoringInterfaceMirror
globals()['MonitoringMatchRule'] = MonitoringMatchRule
globals()['MonitoringMirrorCollector'] = MonitoringMirrorCollector
globals()['MonitoringMirrorSource'] = MonitoringMirrorSource
globals()['MonitoringMirrorStartConditions'] = MonitoringMirrorStartConditions
globals()['MonitoringWorkloadMirror'] = MonitoringWorkloadMirror
from pensando_dss.psm.psm.model.monitoring_mirror_session_spec import MonitoringMirrorSessionSpec


class TestMonitoringMirrorSessionSpec(unittest.TestCase):
    """MonitoringMirrorSessionSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringMirrorSessionSpec(self):
        """Test MonitoringMirrorSessionSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringMirrorSessionSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
