"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
from pensando_dss.psm.model.network_pause_spec import NetworkPauseSpec
globals()['ClusterIPConfig'] = ClusterIPConfig
globals()['NetworkPauseSpec'] = NetworkPauseSpec
from pensando_dss.psm.psm.model.network_network_interface_spec import NetworkNetworkInterfaceSpec


class TestNetworkNetworkInterfaceSpec(unittest.TestCase):
    """NetworkNetworkInterfaceSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkInterfaceSpec(self):
        """Test NetworkNetworkInterfaceSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkInterfaceSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
