"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_auto_msg_route_table_watch_helper_watch_event import NetworkAutoMsgRouteTableWatchHelperWatchEvent
globals()['NetworkAutoMsgRouteTableWatchHelperWatchEvent'] = NetworkAutoMsgRouteTableWatchHelperWatchEvent
from pensando_dss.psm.psm.model.network_auto_msg_route_table_watch_helper import NetworkAutoMsgRouteTableWatchHelper


class TestNetworkAutoMsgRouteTableWatchHelper(unittest.TestCase):
    """NetworkAutoMsgRouteTableWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgRouteTableWatchHelper(self):
        """Test NetworkAutoMsgRouteTableWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgRouteTableWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
