"""
    Objstore API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.objstore_v1_api import ObjstoreV1Api  # noqa: E501


class TestObjstoreV1Api(unittest.TestCase):
    """ObjstoreV1Api unit test stubs"""

    def setUp(self):
        self.api = ObjstoreV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_object(self):
        """Test case for add_object

        Create Object object  # noqa: E501
        """
        pass

    def test_add_object1(self):
        """Test case for add_object1

        Create Object object  # noqa: E501
        """
        pass

    def test_delete_object(self):
        """Test case for delete_object

        Delete Object object  # noqa: E501
        """
        pass

    def test_delete_object1(self):
        """Test case for delete_object1

        Delete Object object  # noqa: E501
        """
        pass

    def test_get_download_file(self):
        """Test case for get_download_file

        Download file  # noqa: E501
        """
        pass

    def test_get_download_file1(self):
        """Test case for get_download_file1

        Download file  # noqa: E501
        """
        pass

    def test_get_download_file_by_prefix(self):
        """Test case for get_download_file_by_prefix

        Download file by prefix  # noqa: E501
        """
        pass

    def test_get_object(self):
        """Test case for get_object

        Get Object object  # noqa: E501
        """
        pass

    def test_get_object1(self):
        """Test case for get_object1

        Get Object object  # noqa: E501
        """
        pass

    def test_list_object(self):
        """Test case for list_object

        List Object objects  # noqa: E501
        """
        pass

    def test_list_object1(self):
        """Test case for list_object1

        List Object objects  # noqa: E501
        """
        pass

    def test_watch_object(self):
        """Test case for watch_object

        Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_object1(self):
        """Test case for watch_object1

        Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
