"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.cluster_configuration_snapshot_spec import ClusterConfigurationSnapshotSpec
from pensando_dss.psm.model.cluster_configuration_snapshot_status import ClusterConfigurationSnapshotStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterConfigurationSnapshotSpec'] = ClusterConfigurationSnapshotSpec
globals()['ClusterConfigurationSnapshotStatus'] = ClusterConfigurationSnapshotStatus
from pensando_dss.psm.psm.model.cluster_configuration_snapshot import ClusterConfigurationSnapshot


class TestClusterConfigurationSnapshot(unittest.TestCase):
    """ClusterConfigurationSnapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterConfigurationSnapshot(self):
        """Test ClusterConfigurationSnapshot"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterConfigurationSnapshot()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
