"""
    Events API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.events_v1_api import EventsV1Api  # noqa: E501


class TestEventsV1Api(unittest.TestCase):
    """EventsV1Api unit test stubs"""

    def setUp(self):
        self.api = EventsV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_get_event(self):
        """Test case for get_get_event

        Get specific event  # noqa: E501
        """
        pass

    def test_get_get_events1(self):
        """Test case for get_get_events1

        """
        pass

    def test_post_get_events(self):
        """Test case for post_get_events

        """
        pass


if __name__ == '__main__':
    unittest.main()
