"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_distributed_service_card_id import ClusterDistributedServiceCardID
from pensando_dss.psm.model.cluster_pnic_info import ClusterPnicInfo
globals()['ClusterDistributedServiceCardID'] = ClusterDistributedServiceCardID
globals()['ClusterPnicInfo'] = ClusterPnicInfo
from pensando_dss.psm.psm.model.cluster_host_spec import ClusterHostSpec


class TestClusterHostSpec(unittest.TestCase):
    """ClusterHostSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterHostSpec(self):
        """Test ClusterHostSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterHostSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
