"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.monitoring_fwlog_policy_spec import MonitoringFwlogPolicySpec
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['MonitoringFwlogPolicySpec'] = MonitoringFwlogPolicySpec
from pensando_dss.psm.psm.model.monitoring_fwlog_policy import MonitoringFwlogPolicy


class TestMonitoringFwlogPolicy(unittest.TestCase):
    """MonitoringFwlogPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringFwlogPolicy(self):
        """Test MonitoringFwlogPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringFwlogPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
