"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_propagation_status import SecurityPropagationStatus
from pensando_dss.psm.model.security_rule_metrics_status import SecurityRuleMetricsStatus
from pensando_dss.psm.model.security_sg_rule_status import SecuritySGRuleStatus
globals()['SecurityPropagationStatus'] = SecurityPropagationStatus
globals()['SecurityRuleMetricsStatus'] = SecurityRuleMetricsStatus
globals()['SecuritySGRuleStatus'] = SecuritySGRuleStatus
from pensando_dss.psm.psm.model.security_network_security_policy_status import SecurityNetworkSecurityPolicyStatus


class TestSecurityNetworkSecurityPolicyStatus(unittest.TestCase):
    """SecurityNetworkSecurityPolicyStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityNetworkSecurityPolicyStatus(self):
        """Test SecurityNetworkSecurityPolicyStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityNetworkSecurityPolicyStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
