"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.workload_migration_source import WorkloadMigrationSource
globals()['WorkloadMigrationSource'] = WorkloadMigrationSource
from pensando_dss.psm.psm.model.workload_endpoint_migration_status import WorkloadEndpointMigrationStatus


class TestWorkloadEndpointMigrationStatus(unittest.TestCase):
    """WorkloadEndpointMigrationStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWorkloadEndpointMigrationStatus(self):
        """Test WorkloadEndpointMigrationStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WorkloadEndpointMigrationStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
