"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.network_network_interface_spec import NetworkNetworkInterfaceSpec
from pensando_dss.psm.model.network_network_interface_status import NetworkNetworkInterfaceStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['NetworkNetworkInterfaceSpec'] = NetworkNetworkInterfaceSpec
globals()['NetworkNetworkInterfaceStatus'] = NetworkNetworkInterfaceStatus
from pensando_dss.psm.psm.model.network_network_interface import NetworkNetworkInterface


class TestNetworkNetworkInterface(unittest.TestCase):
    """NetworkNetworkInterface unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkInterface(self):
        """Test NetworkNetworkInterface"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkInterface()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
