"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.network_v1_api import NetworkV1Api  # noqa: E501


class TestNetworkV1Api(unittest.TestCase):
    """NetworkV1Api unit test stubs"""

    def setUp(self):
        self.api = NetworkV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ipam_policy(self):
        """Test case for add_ipam_policy

        Create IPAMPolicy object  # noqa: E501
        """
        pass

    def test_add_ipam_policy1(self):
        """Test case for add_ipam_policy1

        Create IPAMPolicy object  # noqa: E501
        """
        pass

    def test_add_network(self):
        """Test case for add_network

        Create Network object  # noqa: E501
        """
        pass

    def test_add_network1(self):
        """Test case for add_network1

        Create Network object  # noqa: E501
        """
        pass

    def test_add_policer_profile(self):
        """Test case for add_policer_profile

        Create PolicerProfile object  # noqa: E501
        """
        pass

    def test_add_policer_profile1(self):
        """Test case for add_policer_profile1

        Create PolicerProfile object  # noqa: E501
        """
        pass

    def test_add_routing_config(self):
        """Test case for add_routing_config

        Create RoutingConfig object  # noqa: E501
        """
        pass

    def test_add_static_bindings(self):
        """Test case for add_static_bindings

        Add static bindings  # noqa: E501
        """
        pass

    def test_add_static_bindings1(self):
        """Test case for add_static_bindings1

        Add static bindings  # noqa: E501
        """
        pass

    def test_add_virtual_router(self):
        """Test case for add_virtual_router

        Create VirtualRouter object  # noqa: E501
        """
        pass

    def test_add_virtual_router1(self):
        """Test case for add_virtual_router1

        Create VirtualRouter object  # noqa: E501
        """
        pass

    def test_add_virtual_router_peering_group(self):
        """Test case for add_virtual_router_peering_group

        Create VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_add_virtual_router_peering_group1(self):
        """Test case for add_virtual_router_peering_group1

        Create VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_delete_ipam_policy(self):
        """Test case for delete_ipam_policy

        Delete IPAMPolicy object  # noqa: E501
        """
        pass

    def test_delete_ipam_policy1(self):
        """Test case for delete_ipam_policy1

        Delete IPAMPolicy object  # noqa: E501
        """
        pass

    def test_delete_network(self):
        """Test case for delete_network

        Delete Network object  # noqa: E501
        """
        pass

    def test_delete_network1(self):
        """Test case for delete_network1

        Delete Network object  # noqa: E501
        """
        pass

    def test_delete_policer_profile(self):
        """Test case for delete_policer_profile

        Delete PolicerProfile object  # noqa: E501
        """
        pass

    def test_delete_policer_profile1(self):
        """Test case for delete_policer_profile1

        Delete PolicerProfile object  # noqa: E501
        """
        pass

    def test_delete_routing_config(self):
        """Test case for delete_routing_config

        Delete RoutingConfig object  # noqa: E501
        """
        pass

    def test_delete_virtual_router(self):
        """Test case for delete_virtual_router

        Delete VirtualRouter object  # noqa: E501
        """
        pass

    def test_delete_virtual_router1(self):
        """Test case for delete_virtual_router1

        Delete VirtualRouter object  # noqa: E501
        """
        pass

    def test_delete_virtual_router_peering_group(self):
        """Test case for delete_virtual_router_peering_group

        Delete VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_delete_virtual_router_peering_group1(self):
        """Test case for delete_virtual_router_peering_group1

        Delete VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_get_ipam_policy(self):
        """Test case for get_ipam_policy

        Get IPAMPolicy object  # noqa: E501
        """
        pass

    def test_get_ipam_policy1(self):
        """Test case for get_ipam_policy1

        Get IPAMPolicy object  # noqa: E501
        """
        pass

    def test_get_network(self):
        """Test case for get_network

        Get Network object  # noqa: E501
        """
        pass

    def test_get_network1(self):
        """Test case for get_network1

        Get Network object  # noqa: E501
        """
        pass

    def test_get_network_interface(self):
        """Test case for get_network_interface

        Get NetworkInterface object  # noqa: E501
        """
        pass

    def test_get_policer_profile(self):
        """Test case for get_policer_profile

        Get PolicerProfile object  # noqa: E501
        """
        pass

    def test_get_policer_profile1(self):
        """Test case for get_policer_profile1

        Get PolicerProfile object  # noqa: E501
        """
        pass

    def test_get_route_table(self):
        """Test case for get_route_table

        Get RouteTable object  # noqa: E501
        """
        pass

    def test_get_route_table1(self):
        """Test case for get_route_table1

        Get RouteTable object  # noqa: E501
        """
        pass

    def test_get_routing_config(self):
        """Test case for get_routing_config

        Get RoutingConfig object  # noqa: E501
        """
        pass

    def test_get_virtual_router(self):
        """Test case for get_virtual_router

        Get VirtualRouter object  # noqa: E501
        """
        pass

    def test_get_virtual_router1(self):
        """Test case for get_virtual_router1

        Get VirtualRouter object  # noqa: E501
        """
        pass

    def test_get_virtual_router_peering_group(self):
        """Test case for get_virtual_router_peering_group

        Get VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_get_virtual_router_peering_group1(self):
        """Test case for get_virtual_router_peering_group1

        Get VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_label_ipam_policy(self):
        """Test case for label_ipam_policy

        Label IPAMPolicy object  # noqa: E501
        """
        pass

    def test_label_ipam_policy1(self):
        """Test case for label_ipam_policy1

        Label IPAMPolicy object  # noqa: E501
        """
        pass

    def test_label_network(self):
        """Test case for label_network

        Label Network object  # noqa: E501
        """
        pass

    def test_label_network1(self):
        """Test case for label_network1

        Label Network object  # noqa: E501
        """
        pass

    def test_label_network_interface(self):
        """Test case for label_network_interface

        Label NetworkInterface object  # noqa: E501
        """
        pass

    def test_label_policer_profile(self):
        """Test case for label_policer_profile

        Label PolicerProfile object  # noqa: E501
        """
        pass

    def test_label_policer_profile1(self):
        """Test case for label_policer_profile1

        Label PolicerProfile object  # noqa: E501
        """
        pass

    def test_label_routing_config(self):
        """Test case for label_routing_config

        Label RoutingConfig object  # noqa: E501
        """
        pass

    def test_label_virtual_router(self):
        """Test case for label_virtual_router

        Label VirtualRouter object  # noqa: E501
        """
        pass

    def test_label_virtual_router1(self):
        """Test case for label_virtual_router1

        Label VirtualRouter object  # noqa: E501
        """
        pass

    def test_label_virtual_router_peering_group(self):
        """Test case for label_virtual_router_peering_group

        Label VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_label_virtual_router_peering_group1(self):
        """Test case for label_virtual_router_peering_group1

        Label VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_list_ipam_policy(self):
        """Test case for list_ipam_policy

        List IPAMPolicy objects  # noqa: E501
        """
        pass

    def test_list_ipam_policy1(self):
        """Test case for list_ipam_policy1

        List IPAMPolicy objects  # noqa: E501
        """
        pass

    def test_list_network(self):
        """Test case for list_network

        List Network objects  # noqa: E501
        """
        pass

    def test_list_network1(self):
        """Test case for list_network1

        List Network objects  # noqa: E501
        """
        pass

    def test_list_network_interface(self):
        """Test case for list_network_interface

        List NetworkInterface objects  # noqa: E501
        """
        pass

    def test_list_policer_profile(self):
        """Test case for list_policer_profile

        List PolicerProfile objects  # noqa: E501
        """
        pass

    def test_list_policer_profile1(self):
        """Test case for list_policer_profile1

        List PolicerProfile objects  # noqa: E501
        """
        pass

    def test_list_route_table(self):
        """Test case for list_route_table

        List RouteTable objects  # noqa: E501
        """
        pass

    def test_list_route_table1(self):
        """Test case for list_route_table1

        List RouteTable objects  # noqa: E501
        """
        pass

    def test_list_routing_config(self):
        """Test case for list_routing_config

        List RoutingConfig objects  # noqa: E501
        """
        pass

    def test_list_virtual_router(self):
        """Test case for list_virtual_router

        List VirtualRouter objects  # noqa: E501
        """
        pass

    def test_list_virtual_router1(self):
        """Test case for list_virtual_router1

        List VirtualRouter objects  # noqa: E501
        """
        pass

    def test_list_virtual_router_peering_group(self):
        """Test case for list_virtual_router_peering_group

        List VirtualRouterPeeringGroup objects  # noqa: E501
        """
        pass

    def test_list_virtual_router_peering_group1(self):
        """Test case for list_virtual_router_peering_group1

        List VirtualRouterPeeringGroup objects  # noqa: E501
        """
        pass

    def test_update_ipam_policy(self):
        """Test case for update_ipam_policy

        Update IPAMPolicy object  # noqa: E501
        """
        pass

    def test_update_ipam_policy1(self):
        """Test case for update_ipam_policy1

        Update IPAMPolicy object  # noqa: E501
        """
        pass

    def test_update_network(self):
        """Test case for update_network

        Update Network object  # noqa: E501
        """
        pass

    def test_update_network1(self):
        """Test case for update_network1

        Update Network object  # noqa: E501
        """
        pass

    def test_update_network_interface(self):
        """Test case for update_network_interface

        Update NetworkInterface object  # noqa: E501
        """
        pass

    def test_update_policer_profile(self):
        """Test case for update_policer_profile

        Update PolicerProfile object  # noqa: E501
        """
        pass

    def test_update_policer_profile1(self):
        """Test case for update_policer_profile1

        Update PolicerProfile object  # noqa: E501
        """
        pass

    def test_update_routing_config(self):
        """Test case for update_routing_config

        Update RoutingConfig object  # noqa: E501
        """
        pass

    def test_update_virtual_router(self):
        """Test case for update_virtual_router

        Update VirtualRouter object  # noqa: E501
        """
        pass

    def test_update_virtual_router1(self):
        """Test case for update_virtual_router1

        Update VirtualRouter object  # noqa: E501
        """
        pass

    def test_update_virtual_router_peering_group(self):
        """Test case for update_virtual_router_peering_group

        Update VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_update_virtual_router_peering_group1(self):
        """Test case for update_virtual_router_peering_group1

        Update VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_watch_ipam_policy(self):
        """Test case for watch_ipam_policy

        Watch IPAMPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ipam_policy1(self):
        """Test case for watch_ipam_policy1

        Watch IPAMPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network(self):
        """Test case for watch_network

        Watch Network objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network1(self):
        """Test case for watch_network1

        Watch Network objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_interface(self):
        """Test case for watch_network_interface

        Watch NetworkInterface objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_policer_profile(self):
        """Test case for watch_policer_profile

        Watch PolicerProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_policer_profile1(self):
        """Test case for watch_policer_profile1

        Watch PolicerProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_route_table(self):
        """Test case for watch_route_table

        Watch RouteTable objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_route_table1(self):
        """Test case for watch_route_table1

        Watch RouteTable objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_routing_config(self):
        """Test case for watch_routing_config

        Watch RoutingConfig objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router(self):
        """Test case for watch_virtual_router

        Watch VirtualRouter objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router1(self):
        """Test case for watch_virtual_router1

        Watch VirtualRouter objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router_peering_group(self):
        """Test case for watch_virtual_router_peering_group

        Watch VirtualRouterPeeringGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router_peering_group1(self):
        """Test case for watch_virtual_router_peering_group1

        Watch VirtualRouterPeeringGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
