"""
    Auth API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.auth_ldap_server_status import AuthLdapServerStatus
from pensando_dss.psm.model.auth_radius_server_status import AuthRadiusServerStatus
globals()['AuthLdapServerStatus'] = AuthLdapServerStatus
globals()['AuthRadiusServerStatus'] = AuthRadiusServerStatus
from pensando_dss.psm.psm.model.auth_authentication_policy_status import AuthAuthenticationPolicyStatus


class TestAuthAuthenticationPolicyStatus(unittest.TestCase):
    """AuthAuthenticationPolicyStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthAuthenticationPolicyStatus(self):
        """Test AuthAuthenticationPolicyStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthAuthenticationPolicyStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
