"""
    Telemetry_query API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.fields_selector import FieldsSelector
from pensando_dss.psm.model.telemetry_query_bottom_spec import TelemetryQueryBottomSpec
from pensando_dss.psm.model.telemetry_query_pagination_spec import TelemetryQueryPaginationSpec
from pensando_dss.psm.model.telemetry_query_top_spec import TelemetryQueryTopSpec
globals()['FieldsSelector'] = FieldsSelector
globals()['TelemetryQueryBottomSpec'] = TelemetryQueryBottomSpec
globals()['TelemetryQueryPaginationSpec'] = TelemetryQueryPaginationSpec
globals()['TelemetryQueryTopSpec'] = TelemetryQueryTopSpec
from pensando_dss.psm.psm.model.telemetry_query_metrics_query_spec import TelemetryQueryMetricsQuerySpec


class TestTelemetryQueryMetricsQuerySpec(unittest.TestCase):
    """TelemetryQueryMetricsQuerySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTelemetryQueryMetricsQuerySpec(self):
        """Test TelemetryQueryMetricsQuerySpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TelemetryQueryMetricsQuerySpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
