"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_bootstrap_ipam_options import NetworkBootstrapIPAMOptions
from pensando_dss.psm.model.network_ipam_options import NetworkIPAMOptions
globals()['NetworkBootstrapIPAMOptions'] = NetworkBootstrapIPAMOptions
globals()['NetworkIPAMOptions'] = NetworkIPAMOptions
from pensando_dss.psm.psm.model.network_ipam_binding import NetworkIPAMBinding


class TestNetworkIPAMBinding(unittest.TestCase):
    """NetworkIPAMBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkIPAMBinding(self):
        """Test NetworkIPAMBinding"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkIPAMBinding()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
