"""
    Staging API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.staging_v1_api import StagingV1Api  # noqa: E501


class TestStagingV1Api(unittest.TestCase):
    """StagingV1Api unit test stubs"""

    def setUp(self):
        self.api = StagingV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_buffer(self):
        """Test case for add_buffer

        Create Buffer object  # noqa: E501
        """
        pass

    def test_add_buffer1(self):
        """Test case for add_buffer1

        Create Buffer object  # noqa: E501
        """
        pass

    def test_bulkedit(self):
        """Test case for bulkedit

        Create/Update/Delete multiple objects as part of a single request  # noqa: E501
        """
        pass

    def test_bulkedit1(self):
        """Test case for bulkedit1

        Create/Update/Delete multiple objects as part of a single request  # noqa: E501
        """
        pass

    def test_clear(self):
        """Test case for clear

        Clear operations from a configuration buffer  # noqa: E501
        """
        pass

    def test_clear1(self):
        """Test case for clear1

        Clear operations from a configuration buffer  # noqa: E501
        """
        pass

    def test_commit(self):
        """Test case for commit

        Commit a staged configuration buffer  # noqa: E501
        """
        pass

    def test_commit1(self):
        """Test case for commit1

        Commit a staged configuration buffer  # noqa: E501
        """
        pass

    def test_delete_buffer(self):
        """Test case for delete_buffer

        Delete Buffer object  # noqa: E501
        """
        pass

    def test_delete_buffer1(self):
        """Test case for delete_buffer1

        Delete Buffer object  # noqa: E501
        """
        pass

    def test_get_buffer(self):
        """Test case for get_buffer

        Get Buffer object  # noqa: E501
        """
        pass

    def test_get_buffer1(self):
        """Test case for get_buffer1

        Get Buffer object  # noqa: E501
        """
        pass

    def test_list_buffer(self):
        """Test case for list_buffer

        List Buffer objects  # noqa: E501
        """
        pass

    def test_list_buffer1(self):
        """Test case for list_buffer1

        List Buffer objects  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
