"""
    Browser API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.browser_v1_api import BrowserV1Api  # noqa: E501


class TestBrowserV1Api(unittest.TestCase):
    """BrowserV1Api unit test stubs"""

    def setUp(self):
        self.api = BrowserV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_query1(self):
        """Test case for get_query1

        """
        pass

    def test_get_references(self):
        """Test case for get_references

        """
        pass

    def test_get_referrers(self):
        """Test case for get_referrers

        """
        pass

    def test_post_query(self):
        """Test case for post_query

        """
        pass


if __name__ == '__main__':
    unittest.main()
