"""
    Rollout API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.rollout_v1_api import RolloutV1Api  # noqa: E501


class TestRolloutV1Api(unittest.TestCase):
    """RolloutV1Api unit test stubs"""

    def setUp(self):
        self.api = RolloutV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_rollout(self):
        """Test case for create_rollout

        Start Rollout operation  # noqa: E501
        """
        pass

    def test_get_rollout(self):
        """Test case for get_rollout

        Get Rollout object  # noqa: E501
        """
        pass

    def test_list_rollout(self):
        """Test case for list_rollout

        List Rollout objects  # noqa: E501
        """
        pass

    def test_remove_rollout(self):
        """Test case for remove_rollout

        Remove a Rollout  # noqa: E501
        """
        pass

    def test_stop_rollout(self):
        """Test case for stop_rollout

        Stop a Rollout operation  # noqa: E501
        """
        pass

    def test_update_rollout(self):
        """Test case for update_rollout

        Update Rollout configuration  # noqa: E501
        """
        pass

    def test_watch_rollout(self):
        """Test case for watch_rollout

        Watch Rollout objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
