"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_spec import SysruntimeFlowSpec
globals()['SysruntimeFlowSpec'] = SysruntimeFlowSpec
from pensando_dss.psm.psm.model.sysruntime_hw_connection_spec import SysruntimeHWConnectionSpec


class TestSysruntimeHWConnectionSpec(unittest.TestCase):
    """SysruntimeHWConnectionSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeHWConnectionSpec(self):
        """Test SysruntimeHWConnectionSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeHWConnectionSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
