"""
    Telemetry_query API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.telemetry_query_v1_api import TelemetryQueryV1Api  # noqa: E501


class TestTelemetryQueryV1Api(unittest.TestCase):
    """TelemetryQueryV1Api unit test stubs"""

    def setUp(self):
        self.api = TelemetryQueryV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_metrics1(self):
        """Test case for get_metrics1

        telemetry metrics query  # noqa: E501
        """
        pass

    def test_post_metrics(self):
        """Test case for post_metrics

        telemetry metrics query  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
