"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.cluster_v1_api import ClusterV1Api  # noqa: E501


class TestClusterV1Api(unittest.TestCase):
    """ClusterV1Api unit test stubs"""

    def setUp(self):
        self.api = ClusterV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_configuration_snapshot(self):
        """Test case for add_configuration_snapshot

        Create ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_add_distributed_service_card(self):
        """Test case for add_distributed_service_card

        Create DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_add_distributed_service_entity(self):
        """Test case for add_distributed_service_entity

        Create DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_add_dsc_profile(self):
        """Test case for add_dsc_profile

        Create DSCProfile object  # noqa: E501
        """
        pass

    def test_add_host(self):
        """Test case for add_host

        Create Host object  # noqa: E501
        """
        pass

    def test_add_license(self):
        """Test case for add_license

        Create License object  # noqa: E501
        """
        pass

    def test_add_node(self):
        """Test case for add_node

        Create Node object  # noqa: E501
        """
        pass

    def test_add_tenant(self):
        """Test case for add_tenant

        Create Tenant object  # noqa: E501
        """
        pass

    def test_auth_bootstrap_complete(self):
        """Test case for auth_bootstrap_complete

        Mark bootstrapping as complete for the cluster  # noqa: E501
        """
        pass

    def test_delete_configuration_snapshot(self):
        """Test case for delete_configuration_snapshot

        Delete ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_delete_distributed_service_card(self):
        """Test case for delete_distributed_service_card

        Delete DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_delete_distributed_service_entity(self):
        """Test case for delete_distributed_service_entity

        Delete DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_delete_dsc_profile(self):
        """Test case for delete_dsc_profile

        Delete DSCProfile object  # noqa: E501
        """
        pass

    def test_delete_host(self):
        """Test case for delete_host

        Delete Host object  # noqa: E501
        """
        pass

    def test_delete_node(self):
        """Test case for delete_node

        Delete Node object  # noqa: E501
        """
        pass

    def test_delete_tenant(self):
        """Test case for delete_tenant

        Delete Tenant object  # noqa: E501
        """
        pass

    def test_get_cluster(self):
        """Test case for get_cluster

        Get Cluster object  # noqa: E501
        """
        pass

    def test_get_cluster_profile(self):
        """Test case for get_cluster_profile

        Get ClusterProfile object  # noqa: E501
        """
        pass

    def test_get_configuration_snapshot(self):
        """Test case for get_configuration_snapshot

        Get ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_get_distributed_service_card(self):
        """Test case for get_distributed_service_card

        Get DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_get_distributed_service_entity(self):
        """Test case for get_distributed_service_entity

        Get DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_get_dsc_profile(self):
        """Test case for get_dsc_profile

        Get DSCProfile object  # noqa: E501
        """
        pass

    def test_get_host(self):
        """Test case for get_host

        Get Host object  # noqa: E501
        """
        pass

    def test_get_license(self):
        """Test case for get_license

        Get License object  # noqa: E501
        """
        pass

    def test_get_node(self):
        """Test case for get_node

        Get Node object  # noqa: E501
        """
        pass

    def test_get_snapshot_restore(self):
        """Test case for get_snapshot_restore

        Get SnapshotRestore object  # noqa: E501
        """
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        Get Tenant object  # noqa: E501
        """
        pass

    def test_get_version(self):
        """Test case for get_version

        Get Version object  # noqa: E501
        """
        pass

    def test_label_cluster(self):
        """Test case for label_cluster

        Label Cluster object  # noqa: E501
        """
        pass

    def test_label_cluster_profile(self):
        """Test case for label_cluster_profile

        Label ClusterProfile object  # noqa: E501
        """
        pass

    def test_label_configuration_snapshot(self):
        """Test case for label_configuration_snapshot

        Label ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_label_distributed_service_card(self):
        """Test case for label_distributed_service_card

        Label DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_label_distributed_service_entity(self):
        """Test case for label_distributed_service_entity

        Label DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_label_dsc_profile(self):
        """Test case for label_dsc_profile

        Label DSCProfile object  # noqa: E501
        """
        pass

    def test_label_host(self):
        """Test case for label_host

        Label Host object  # noqa: E501
        """
        pass

    def test_label_license(self):
        """Test case for label_license

        Label License object  # noqa: E501
        """
        pass

    def test_label_node(self):
        """Test case for label_node

        Label Node object  # noqa: E501
        """
        pass

    def test_label_tenant(self):
        """Test case for label_tenant

        Label Tenant object  # noqa: E501
        """
        pass

    def test_list_distributed_service_card(self):
        """Test case for list_distributed_service_card

        List DistributedServiceCard objects  # noqa: E501
        """
        pass

    def test_list_distributed_service_entity(self):
        """Test case for list_distributed_service_entity

        List DistributedServiceEntity objects  # noqa: E501
        """
        pass

    def test_list_dsc_profile(self):
        """Test case for list_dsc_profile

        List DSCProfile objects  # noqa: E501
        """
        pass

    def test_list_host(self):
        """Test case for list_host

        List Host objects  # noqa: E501
        """
        pass

    def test_list_node(self):
        """Test case for list_node

        List Node objects  # noqa: E501
        """
        pass

    def test_list_tenant(self):
        """Test case for list_tenant

        List Tenant objects  # noqa: E501
        """
        pass

    def test_restore(self):
        """Test case for restore

        Restore Configuration  # noqa: E501
        """
        pass

    def test_save(self):
        """Test case for save

        Perform a Configuation Snapshot  # noqa: E501
        """
        pass

    def test_update_cluster(self):
        """Test case for update_cluster

        Update Cluster object  # noqa: E501
        """
        pass

    def test_update_cluster_profile(self):
        """Test case for update_cluster_profile

        Update ClusterProfile object  # noqa: E501
        """
        pass

    def test_update_configuration_snapshot(self):
        """Test case for update_configuration_snapshot

        Update ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_update_distributed_service_card(self):
        """Test case for update_distributed_service_card

        Update DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_update_distributed_service_entity(self):
        """Test case for update_distributed_service_entity

        Update DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_update_dsc_profile(self):
        """Test case for update_dsc_profile

        Update DSCProfile object  # noqa: E501
        """
        pass

    def test_update_host(self):
        """Test case for update_host

        Update Host object  # noqa: E501
        """
        pass

    def test_update_license(self):
        """Test case for update_license

        Update License object  # noqa: E501
        """
        pass

    def test_update_node(self):
        """Test case for update_node

        Update Node object  # noqa: E501
        """
        pass

    def test_update_tenant(self):
        """Test case for update_tenant

        Update Tenant object  # noqa: E501
        """
        pass

    def test_update_tls_config(self):
        """Test case for update_tls_config

        Update TLS Configuration for cluster  # noqa: E501
        """
        pass

    def test_update_version(self):
        """Test case for update_version

        Update Version object  # noqa: E501
        """
        pass

    def test_watch_cluster(self):
        """Test case for watch_cluster

        Watch Cluster objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_cluster_profile(self):
        """Test case for watch_cluster_profile

        Watch ClusterProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_configuration_snapshot(self):
        """Test case for watch_configuration_snapshot

        Watch ConfigurationSnapshot objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_distributed_service_card(self):
        """Test case for watch_distributed_service_card

        Watch DistributedServiceCard objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_distributed_service_entity(self):
        """Test case for watch_distributed_service_entity

        Watch DistributedServiceEntity objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_dsc_profile(self):
        """Test case for watch_dsc_profile

        Watch DSCProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_host(self):
        """Test case for watch_host

        Watch Host objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_node(self):
        """Test case for watch_node

        Watch Node objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_tenant(self):
        """Test case for watch_tenant

        Watch Tenant objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_version(self):
        """Test case for watch_version

        Watch Version objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
