"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.psm.model.evpn_route_evpn_type5_route import EVPNRouteEVPNType5Route


class TestEVPNRouteEVPNType5Route(unittest.TestCase):
    """EVPNRouteEVPNType5Route unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEVPNRouteEVPNType5Route(self):
        """Test EVPNRouteEVPNType5Route"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EVPNRouteEVPNType5Route()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
