"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_key_l2 import SysruntimeFlowKeyL2
from pensando_dss.psm.model.sysruntime_flow_key_v4 import SysruntimeFlowKeyV4
globals()['SysruntimeFlowKeyL2'] = SysruntimeFlowKeyL2
globals()['SysruntimeFlowKeyV4'] = SysruntimeFlowKeyV4
from pensando_dss.psm.psm.model.sysruntime_flow_key import SysruntimeFlowKey


class TestSysruntimeFlowKey(unittest.TestCase):
    """SysruntimeFlowKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeFlowKey(self):
        """Test SysruntimeFlowKey"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeFlowKey()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
